EXPORTS
	?ImplementationGroupProxy@@YAPBUTImplementationProxy@@AAH@Z @ 1 NONAME ; struct TImplementationProxy const * ImplementationGroupProxy(int &)
	?AddNewL@CFsHuiScrollbarLayout@@SAPAV1@AAVCHuiControl@@PAVCHuiLayout@@@Z @ 2 NONAME ; class CFsHuiScrollbarLayout * CFsHuiScrollbarLayout::AddNewL(class CHuiControl &, class CHuiLayout *)
	?IsScrollbarVisible@CFsHuiScrollbarLayout@@QAEHW4TFsScrollbar@@@Z @ 3 NONAME ; int CFsHuiScrollbarLayout::IsScrollbarVisible(enum TFsScrollbar)
	?LayoutSize@CFsHuiScrollbarLayout@@QAE?AVTHuiRealPoint@@XZ @ 4 NONAME ; class THuiRealPoint CFsHuiScrollbarLayout::LayoutSize(void)
	?RangeEnd@CFsHuiScrollbarLayout@@QAEHW4TFsScrollbar@@@Z @ 5 NONAME ; int CFsHuiScrollbarLayout::RangeEnd(enum TFsScrollbar)
	?RangeStart@CFsHuiScrollbarLayout@@QAEHW4TFsScrollbar@@@Z @ 6 NONAME ; int CFsHuiScrollbarLayout::RangeStart(enum TFsScrollbar)
	?ScrollbarPos@CFsHuiScrollbarLayout@@QAEHW4TFsScrollbar@@@Z @ 7 NONAME ; int CFsHuiScrollbarLayout::ScrollbarPos(enum TFsScrollbar)
	?SetHorizontalScrollbarHeight@CFsHuiScrollbarLayout@@QAEXHH@Z @ 8 NONAME ; void CFsHuiScrollbarLayout::SetHorizontalScrollbarHeight(int, int)
	?SetRange@CFsHuiScrollbarLayout@@QAEXHHW4TFsScrollbar@@@Z @ 9 NONAME ; void CFsHuiScrollbarLayout::SetRange(int, int, enum TFsScrollbar)
	?SetScrollbarImagesL@CFsHuiScrollbarLayout@@QAEXPAVCHuiImageBrush@@0W4TFsScrollbar@@@Z @ 10 NONAME ; void CFsHuiScrollbarLayout::SetScrollbarImagesL(class CHuiImageBrush *, class CHuiImageBrush *, enum TFsScrollbar)
	?SetScrollbarPos@CFsHuiScrollbarLayout@@QAEXHW4TFsScrollbar@@@Z @ 11 NONAME ; void CFsHuiScrollbarLayout::SetScrollbarPos(int, enum TFsScrollbar)
	?SetSize@CFsHuiScrollbarLayout@@UAEXABVTHuiRealSize@@H@Z @ 12 NONAME ; void CFsHuiScrollbarLayout::SetSize(class THuiRealSize const &, int)
	?SetThumbSpan@CFsHuiScrollbarLayout@@QAEXHW4TFsScrollbar@@@Z @ 13 NONAME ; void CFsHuiScrollbarLayout::SetThumbSpan(int, enum TFsScrollbar)
	?SetVerticalScrollbarWidth@CFsHuiScrollbarLayout@@QAEXHH@Z @ 14 NONAME ; void CFsHuiScrollbarLayout::SetVerticalScrollbarWidth(int, int)
	?SetVisibilityMode@CFsHuiScrollbarLayout@@QAEXW4TFsScrollbarVisibility@@W4TFsScrollbar@@@Z @ 15 NONAME ; void CFsHuiScrollbarLayout::SetVisibilityMode(enum TFsScrollbarVisibility, enum TFsScrollbar)
	?ThumbSpan@CFsHuiScrollbarLayout@@QAEHW4TFsScrollbar@@@Z @ 16 NONAME ; int CFsHuiScrollbarLayout::ThumbSpan(enum TFsScrollbar)
	?Update@CFsHuiScrollbarLayout@@QAEXH@Z @ 17 NONAME ; void CFsHuiScrollbarLayout::Update(int)
	?UpdateChildLayout@CFsHuiScrollbarLayout@@UAEXHH@Z @ 18 NONAME ; void CFsHuiScrollbarLayout::UpdateChildLayout(int, int)
	?VisibilityMode@CFsHuiScrollbarLayout@@QAE?AW4TFsScrollbarVisibility@@W4TFsScrollbar@@@Z @ 19 NONAME ; enum TFsScrollbarVisibility CFsHuiScrollbarLayout::VisibilityMode(enum TFsScrollbar)

